/*
 * Copyright 2010-2011 Craig S. Dickson (http://craigsdickson.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.squeakysand.osgi.framework;

import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 *
 * @author <a href="http://craigsdickson.com">Craig S. Dickson</a>
 */
public class BasicBundleActivator implements BundleActivator {

    private static final Logger LOG = LoggerFactory.getLogger(BasicBundleActivator.class);

    private Logger logger;
    private BundleContext context;

    public BasicBundleActivator() {
        this(LOG);
    }

    public BasicBundleActivator(Logger logger) {
        if (logger == null) {
            this.logger = LOG;
        } else {
            this.logger = logger;
        }
    }

    @Override
    public void start(BundleContext context) throws Exception {
        this.context = context;
        logger.info(context.getBundle().getSymbolicName() + " started");
    }

    @Override
    public void stop(BundleContext context) throws Exception {
        this.context = null;
        logger.info(context.getBundle().getSymbolicName() + " stopped");
    }

    public BundleContext getContext() {
        return context;
    }

}
