/*
 * Copyright 2010-2011 Craig S. Dickson (http://craigsdickson.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.squeakysand.osgi.framework;

import org.osgi.framework.ServiceEvent;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.squeakysand.commons.util.Predicate;
import org.osgi.framework.ServiceListener;

/**
 * @author <a href="http://craigsdickson.com">Craig S. Dickson</a>
 */
public class LoggingServiceListener implements ServiceListener {

    private static final Logger LOG = LoggerFactory.getLogger(LoggingServiceListener.class);

    private Logger logger;
    private Predicate<? super ServiceEvent> eventFilter;

    public LoggingServiceListener() {
        this(LOG);
    }

    public LoggingServiceListener(Logger logger) {
        this.logger = logger;
        setDefaultPredicate();
    }

    public void setEventFilter(Predicate<? super ServiceEvent> eventFilter) {
        if (eventFilter == null) {
            setDefaultPredicate();
        } else {
            this.eventFilter = eventFilter;
        }
    }

    @Override
    public void serviceChanged(ServiceEvent event) {
        if (eventFilter.evaluate(event)) {
            logger.info(event.toString());
        }
    }

    private void setDefaultPredicate() {
        eventFilter = Predicate.ALWAYS_TRUE;
    }

}
